;*******************************************************************************
;  psi.nsi v1.6 - NSIS script for installing Psi 0.9.2
;  Copyright  2004 Mircea Ionut Bardac (IceRAM)
;
;  This program is free software; you can redistribute it and/or
;  modify it under the terms of the GNU General Public License
;  as published by the Free Software Foundation; either version 2
;  of the License, or (at your option) any later version.
; 
;  This program is distributed in the hope that it will be useful,
;  but WITHOUT ANY WARRANTY; without even the implied warranty of
;  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
;  GNU General Public License for more details.
; 
;  You should have received a copy of the GNU General Public License
;  along with this file; if not, write to the Free Software
;  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
;
;  See ReadME.txt for more information on the script.
;*******************************************************************************

; Installer Script Version
!define INSTALLER_VERSION "1.6"

!define INSTALLER_BUILD "1"
; ^ update whenever you add something to the installer and rebuild it
;   without changing APPVERSION
; ^ reset to 0 when you change APPVERSION

;!define BUILD_WITH_LANGPACKS
; ^ comment if you want to build the installer without language packs

;!define LANG_TEST_BUILD
; ^ uncomment if you want to build a test installer

!ifdef LANG_TEST_BUILD
 !ifndef BUILD_WITH_LANGPACKS
  !define BUILD_WITH_LANGPACKS
 !endif
!endif

; Application name
!define APPNAME "Tkabber-Pack"
!define APPVERSION "0.9.7.0"
!define APPNAMEANDVERSION "${APPNAME} ${APPVERSION}"

!define LCAPPNAME "tkabber-pack" ; lowercase APPNAME

; Version information for the installer executable
VIAddVersionKey ProductName "${APPNAME}"
VIAddVersionKey ProductVersion "${APPVERSION}"
VIAddVersionKey Comments "${APPNAMEANDVERSION} Installer - Win32 Installer v${INSTALLER_VERSION} build ${INSTALLER_BUILD}  2004 Badlop / NSIS Script v${INSTALLER_VERSION}  2004 Mircea Ionut Bardac (IceRAM)"
VIAddVersionKey CompanyName ""
VIAddVersionKey LegalCopyright ""
VIAddVersionKey FileDescription "${APPNAMEANDVERSION} Installer (build ${INSTALLER_BUILD}) - Win32 Installer v${INSTALLER_VERSION}"
VIAddVersionKey FileVersion "${INSTALLER_VERSION}b${INSTALLER_BUILD}"
VIAddVersionKey InternalName "${APPNAMEANDVERSION} Installer  (build ${INSTALLER_BUILD}) - Win32 Installer v${INSTALLER_VERSION}"
VIAddVersionKey LegalTrademarks ""
!ifdef LANG_TEST_BUILD
  VIAddVersionKey OriginalFilename "${LCAPPNAME}-${APPVERSION}-win-langtest.exe"
  VIAddVersionKey PrivateBuild "Language Packs Included: all available"
!else
 !ifdef BUILD_WITH_LANGPACKS
  VIAddVersionKey OriginalFilename "${LCAPPNAME}-${APPVERSION}-win-setup.exe"
  VIAddVersionKey PrivateBuild "Language Packs Included: CA, CS, DE, EL, ES, FR, IT, PL, MK, NL, SE, SK, ZH"
 !else
  VIAddVersionKey OriginalFilename "${LCAPPNAME}-${APPVERSION}-win-setup-base.exe"
  VIAddVersionKey PrivateBuild "Language Packs Included: none"
 !endif
!endif
VIAddVersionKey SpecialBuild "Build number: ${INSTALLER_BUILD}"
VIProductVersion "${APPVERSION}.${INSTALLER_BUILD}"

SetCompressor lzma

Var DONE_INIT
Var RUN_BY_ADMIN
Var INST_CONTEXT

var LSTR_SHORTCUTS
var LSTR_CURRENTUSER
var LSTR_ALLUSERS
var LSTR_QUICKLAUNCH
var LSTR_DESKTOP_S
var LSTR_STARTMENU_GROUP
var LSTR_ASK_EXIT_PSI
var LSTR_UNINST_RUNNING
var LSTR_INST_RUNNING
var LSTR_WARN_ADMIN_1
var LSTR_WARN_ADMIN_2
var LSTR_PSIBASE
var LSTR_LANGUAGES
var LSTR_AUTOSTART
var LSTR_A_INSTALLED
var LSTR_ERR_UNINST

!include "Sections.nsh"
!include "installer-functions.nsh"

!define XPSTYLE on

BrandingText "- ${APPNAMEANDVERSION} installer - build ${INSTALLER_BUILD}  2004 Badlop / script ver. ${INSTALLER_VERSION}  2004 Mircea Ionut Bardac (IceRAM) "
!define HOME_URL "http://tkabber.jabber.ru/"

!define INSTALLER_SOURCE "E:\Tkabber-Pack"

; Main Install settings
Name "${APPNAMEANDVERSION}"
InstallDir "$PROGRAMFILES\Tkabber"
!ifdef LANG_TEST_BUILD
 OutFile "${LCAPPNAME}-${APPVERSION}-win-langtest.exe"
!else
 !ifdef BUILD_WITH_LANGPACKS
  OutFile "${LCAPPNAME}-${APPVERSION}-win-setup.exe"
 !else
  OutFile "${LCAPPNAME}-${APPVERSION}.exe"
 !endif
!endif

InstallDirRegKey HKLM "Software\${APPNAME}" ""

; Modern interface settings
!include "MUI.nsh"

;--------------------------------
;Page settings
!define MUI_ICON "${INSTALLER_SOURCE}\install.ico"
!define MUI_UNICON "${INSTALLER_SOURCE}\uninstall.ico"

!define MUI_HEADERIMAGE
!define MUI_HEADERIMAGE_BITMAP "${INSTALLER_SOURCE}\psi-header-l.bmp"
!define MUI_HEADERIMAGE_BITMAP_RTL "${INSTALLER_SOURCE}\psi-header-r.bmp"
!define MUI_HEADERIMAGE_UNBITMAP "${INSTALLER_SOURCE}\psi-header-l.bmp"
!define MUI_HEADERIMAGE_UNBITMAP_RTL "${INSTALLER_SOURCE}\psi-header-r.bmp"

!define MUI_ABORTWARNING
!define MUI_COMPONENTSPAGE_NODESC

!define MUI_FINISHPAGE_RUN "$INSTDIR\Tkabber.exe"
;!define MUI_FINISHPAGE_SHOWREADME "$INSTDIR\Readme.txt"

!define MUI_FINISHPAGE_LINK "http://tkabber.jabber.ru/"
!define MUI_FINISHPAGE_LINK_LOCATION "http://tkabber.jabber.ru/"

!define MUI_WELCOMEFINISHPAGE_BITMAP "${INSTALLER_SOURCE}\psi-l.bmp"
!define MUI_UNWELCOMEFINISHPAGE_BITMAP "${INSTALLER_SOURCE}\psi-l.bmp"
;!define MUI_LICENSEPAGE_CHECKBOX

;--------------------------------
;Language Selection Dialog Settings

  ;Remember the installer language
  !define MUI_LANGDLL_REGISTRY_ROOT "HKLM"
  !define MUI_LANGDLL_REGISTRY_KEY "Software\${APPNAME}"
  !define MUI_LANGDLL_REGISTRY_VALUENAME "Installer Language"

PAGE custom InitRoutines
!insertmacro MUI_PAGE_WELCOME
!insertmacro MUI_PAGE_LICENSE "${INSTALLER_SOURCE}\psi_app\COPYING"
!insertmacro MUI_PAGE_COMPONENTS
!insertmacro MUI_PAGE_DIRECTORY
!insertmacro MUI_PAGE_INSTFILES
!insertmacro MUI_PAGE_FINISH

UNINSTPAGE custom un.InitRoutines
!insertmacro MUI_UNPAGE_WELCOME
!insertmacro MUI_UNPAGE_CONFIRM
!insertmacro MUI_UNPAGE_INSTFILES
!insertmacro MUI_UNPAGE_FINISH

;--------------------------------
; Languages
  !include "installer-languages.nsh"

;--------------------------------
;Reserve Files
  !insertmacro MUI_RESERVEFILE_LANGDLL
;--------------------------------

; macro for creating urls
!Macro "CreateURL" "URLFile" "URLSite"
WriteINIStr "$INSTDIR\${URLFile}.url" "InternetShortcut" "URL" "${URLSite}"
!macroend
;--------------------------------

;*********************************
; Sections of the installer

Section "!$LSTR_PSIBASE" SectionBase
  ; Set Section properties
  SetOverwrite on
  SectionIn RO
  ; Set Section Files and Shortcuts
  SetOutPath "$INSTDIR\"
!ifndef LANG_TEST_BUILD
 !include "psi_files_install.nsi"
!else
  File "${INSTALLER_SOURCE}\psi_app\COPYING" ;install only one file when LANG_TEST_BUILD
!endif
  SetOutPath "$INSTDIR\"
;  !insertmacro "CreateURL" "Psi - Home page" "http://psi.affinix.com/"
;  !insertmacro "CreateURL" "Psi - Forum" "http://psi.affinix.com/forums/"
;  !insertmacro "CreateURL" "Psi - Documentation" "http://psi.affinix.com/psi_docs/"
SectionEnd

; ********************************

!ifdef BUILD_WITH_LANGPACKS
SubSection "$LSTR_LANGUAGES" SectionLang
; Catalan
Section /o "Catalan" LangCA
  SetOverwrite on
  SetOutPath "$INSTDIR\"
  File "${INSTALLER_SOURCE}\psi_lang\psi_ca.qm"
SectionEnd

; Czech
Section /o "Czech" LangCS
  SetOverwrite on
  SetOutPath "$INSTDIR\"
  File "${INSTALLER_SOURCE}\psi_lang\psi_cs.qm"
SectionEnd

; Dutch
Section /o "Dutch" LangNL
  SetOverwrite on
  SetOutPath "$INSTDIR\"
  File "${INSTALLER_SOURCE}\psi_lang\psi_nl.qm"
SectionEnd

; French
Section /o "French" LangFR
  SetOverwrite on
  SetOutPath "$INSTDIR\"
  File "${INSTALLER_SOURCE}\psi_lang\psi_fr.qm"
SectionEnd

; German
Section /o "German" LangDE
  SetOverwrite on
  SetOutPath "$INSTDIR\"
  File "${INSTALLER_SOURCE}\psi_lang\psi_de.qm"
SectionEnd

; Greek
Section /o "Greek" LangGR
  SetOverwrite on
  SetOutPath "$INSTDIR\"
  File "${INSTALLER_SOURCE}\psi_lang\psi_el.qm"
SectionEnd

; Italian
Section /o "Italian" LangIT
  SetOverwrite on
  SetOutPath "$INSTDIR\"
  File "${INSTALLER_SOURCE}\psi_lang\psi_it.qm"
SectionEnd

; Macedonian
Section /o "Macedonian" LangMK
  SetOverwrite on
  SetOutPath "$INSTDIR\"
  File "${INSTALLER_SOURCE}\psi_lang\psi_mk.qm"
SectionEnd

; Polish
Section /o "Polish" LangPL
  SetOverwrite on
  SetOutPath "$INSTDIR\"
  File "${INSTALLER_SOURCE}\psi_lang\psi_pl.qm"
SectionEnd

; Simplified Chinese
Section /o "Simplified Chinese" LangZH
  SetOverwrite on
  SetOutPath "$INSTDIR\"
  File "${INSTALLER_SOURCE}\psi_lang\psi_zh.qm"
SectionEnd

; Slovak
Section /o "Slovak" LangSK
  SetOverwrite on
  SetOutPath "$INSTDIR\"
  File "${INSTALLER_SOURCE}\psi_lang\psi_sk.qm"
SectionEnd

; Spanish
Section /o "Spanish" LangES
  SetOverwrite on
  SetOutPath "$INSTDIR\"
  File "${INSTALLER_SOURCE}\psi_lang\psi_es.qm"
SectionEnd

; Swedish
Section /o "Swedish" LangSE
  SetOverwrite on
  SetOutPath "$INSTDIR\"
  File "${INSTALLER_SOURCE}\psi_lang\psi_se.qm"
SectionEnd

; *** FOLLOW THE PATTERN WHEN ADDING LANGUAGES
SubSectionEnd
!endif

Section "$LSTR_STARTMENU_GROUP ($INST_CONTEXT)" SectionSM
 StrCmp $RUN_BY_ADMIN "true" sm_admin
 sm_normal:
  SetShellVarContext current
  Goto sm_done
 sm_admin:
  SetShellVarContext all
 sm_done:
  CreateDirectory "$SMPROGRAMS\Tkabber"
  SetOutPath "$INSTDIR\"
;  CreateShortCut "$SMPROGRAMS\Psi\Psi - Forum.lnk" "$INSTDIR\Psi - Forum.url"
;  CreateShortCut "$SMPROGRAMS\Psi\Psi - Documentation.lnk" "$INSTDIR\Psi - Documentation.url"
;  CreateShortCut "$SMPROGRAMS\Psi\Psi - Home page.lnk" "$INSTDIR\Psi - Home page.url"
  CreateShortCut "$SMPROGRAMS\Tkabber\Tkabber.lnk" "$INSTDIR\Tkabber.exe"
  CreateShortCut "$SMPROGRAMS\Tkabber\Uninstall.lnk" "$INSTDIR\uninstall.exe"
;  CreateShortCut "$SMPROGRAMS\Psi\ReadME.lnk" "$INSTDIR\Readme.txt"
  SetShellVarContext current
SectionEnd

; ********************************
SubSection "$LSTR_SHORTCUTS ($LSTR_CURRENTUSER)" SectionShortcuts
  Section "$LSTR_DESKTOP_S" SectionSD
   SetShellVarContext current
   SetOutPath "$INSTDIR\"
   CreateShortCut "$DESKTOP\Tkabber.lnk" "$INSTDIR\Tkabber.exe"
  SectionEnd
  Section /o "$LSTR_QUICKLAUNCH" SectionQuickLaunch
   SetShellVarContext current
   SetOutPath "$INSTDIR\"
   CreateShortCut "$QUICKLAUNCH\Tkabber.lnk" "$INSTDIR\Tkabber.exe"
  SectionEnd
SubSectionEnd

Section "$LSTR_AUTOSTART ($LSTR_CURRENTUSER)" SectionAutomaticStartup
  SetShellVarContext current
  SetOutPath "$INSTDIR\"
  CreateShortCut "$SMSTARTUP\Tkabber.lnk" "$INSTDIR\Tkabber.exe"
;  WriteRegStr HKCU "Software\Microsoft\Windows\CurrentVersion\Run" "Psi" "$INSTDIR\Psi.exe"
;  ^ doesn't work - Psi is not started with the correct working dir
SectionEnd

Section -FinishSection
 StrCmp $RUN_BY_ADMIN "true" lastsettings_is_admin
  WriteRegStr HKCU "Software\${APPNAME}" "" "$INSTDIR"
  WriteRegStr HKCU "Software\${APPNAME}" "Version" "${APPVERSION}"
  WriteRegStr HKCU "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPNAME}" "DisplayName" "${APPNAME} (remove only)"
  WriteRegStr HKCU "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPNAME}" "UninstallString" "$INSTDIR\uninstall.exe"
  Goto lastsettings_done
 lastsettings_is_admin:
  WriteRegStr HKLM "Software\Affinix\${APPNAME}" "" "$INSTDIR"
  WriteRegStr HKLM "Software\Affinix\${APPNAME}" "Version" "${APPVERSION}"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPNAME}" "DisplayName" "${APPNAME} (remove only)"
  WriteRegStr HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPNAME}" "UninstallString" "$INSTDIR\uninstall.exe"

 lastsettings_done:
 WriteUninstaller "$INSTDIR\uninstall.exe"
SectionEnd

; ***************************************
; installer initialization

Function InitRoutines

 StrCmp $DONE_INIT "1" done_init

 StrCpy $DONE_INIT "1"

; MessageBox MB_OK "Installing in $LANGUAGE"

; initializing the strings with the coresponding ones in the active language
 StrCpy $LSTR_PSIBASE         "Tkabber"
 StrCpy $LSTR_LANGUAGES       "Languages"
 StrCpy $LSTR_CURRENTUSER     "Current User"
 StrCpy $LSTR_ALLUSERS        "All Users"
 StrCpy $LSTR_SHORTCUTS       "Shortcuts"
 StrCpy $LSTR_QUICKLAUNCH     "Quick Launch shortcut"
 StrCpy $LSTR_DESKTOP_S       "Desktop shortcut"
 StrCpy $LSTR_STARTMENU_GROUP "Start Menu group"
 StrCpy $LSTR_AUTOSTART       "Automatic startup"
 StrCpy $LSTR_ASK_EXIT_PSI    "You must exit all running copies of Tkabber to continue!"
 StrCpy $LSTR_UNINST_RUNNING  "The uninstaller is already running."
 StrCpy $LSTR_INST_RUNNING    "The installer is already running."
 StrCpy $LSTR_WARN_ADMIN_1    "You are running this installer as a normal user, NOT as an Administrator."
 StrCpy $LSTR_WARN_ADMIN_2    "If you want to uninstall this application, you must use the same user or your system may become unstable."
 StrCpy $LSTR_A_INSTALLED     "Tkabber is already installed. $\n$\nClick <OK> to remove the previous version or <Cancel> to cancel this upgrade."
 StrCpy $LSTR_ERR_UNINST      "There were some errors uninstalling Tkabber. $\n$\nWould you like to continue?"

 ;StrCmp $(STR_PSIBASE) "" +2
 ;   StrCpy $LSTR_PSIBASE $(STR_PSIBASE)
 StrCmp $(STR_LANGUAGES) "" +2
    StrCpy $LSTR_LANGUAGES $(STR_LANGUAGES)
 StrCmp $(STR_CURRENTUSER) "" +2
    StrCpy $LSTR_CURRENTUSER $(STR_CURRENTUSER)
 StrCmp $(STR_ALLUSERS) "" +2
    StrCpy $LSTR_ALLUSERS $(STR_ALLUSERS)
 StrCmp $(STR_SHORTCUTS) "" +2
    StrCpy $LSTR_SHORTCUTS $(STR_SHORTCUTS)
 StrCmp $(STR_QUICKLAUNCH) "" +2
    StrCpy $LSTR_QUICKLAUNCH $(STR_QUICKLAUNCH)
 StrCmp $(STR_DESKTOP_S) "" +2
    StrCpy $LSTR_DESKTOP_S $(STR_DESKTOP_S)
 StrCmp $(STR_STARTMENU_GROUP) "" +2
    StrCpy $LSTR_STARTMENU_GROUP $(STR_STARTMENU_GROUP)
 StrCmp $(STR_AUTOSTART) "" +2
    StrCpy $LSTR_AUTOSTART $(STR_AUTOSTART)
 StrCmp $(STR_ASK_EXIT_PSI) "" +2
    StrCpy $LSTR_ASK_EXIT_PSI $(STR_ASK_EXIT_PSI)
 StrCmp $(STR_UNINST_RUNNING) "" +2
    StrCpy $LSTR_UNINST_RUNNING $(STR_UNINST_RUNNING)
 StrCmp $(STR_INST_RUNNING) "" +2
    StrCpy $LSTR_INST_RUNNING $(STR_INST_RUNNING)
 StrCmp $(STR_WARN_ADMIN_1) "" +2
    StrCpy $LSTR_WARN_ADMIN_1 $(STR_WARN_ADMIN_1)
 StrCmp $(STR_WARN_ADMIN_2) "" +2
    StrCpy $LSTR_WARN_ADMIN_2 $(STR_WARN_ADMIN_2)
 StrCmp $(STR_A_INSTALLED) "" +2
    StrCpy $LSTR_A_INSTALLED $(STR_A_INSTALLED)
 StrCmp $(STR_ERR_UNINST) "" +2
    StrCpy $LSTR_ERR_UNINST $(STR_ERR_UNINST)

; allow only one instance of the installer
  System::Call 'kernel32::CreateMutexA(i 0, i 0, t "Tkabber-Pack${APPVERSION}") i .r1 ?e'
  Pop $R0
  StrCmp $R0 0 +3
    MessageBox MB_OK "$LSTR_INST_RUNNING"
    Quit
; ****************

; check for an existing installation of Psi
  Call UninstallPreviousPsi
; ****************

; close active Psi sessions
  ;Call ClosePsiInstances
; ****************

 Call IsUserAdmin
 Pop $R0
 StrCpy $RUN_BY_ADMIN $R0 ; saving information
 StrCmp $R0 "true" is_admin
   ; not an admin
   MessageBox MB_OK|MB_ICONINFORMATION "$LSTR_WARN_ADMIN_1$\n$\n$LSTR_WARN_ADMIN_2"
   StrCpy $INST_CONTEXT $LSTR_CURRENTUSER
   goto done_init
 is_admin:
   StrCpy $INST_CONTEXT $LSTR_ALLUSERS
 done_init:

FunctionEnd

Function .onInit
; permit the user to choose the installer language
; the setting will be used to automatically select a language pack if availaible
  !insertmacro MUI_LANGDLL_DISPLAY
; ****************

; expand Shorcuts Section
  SectionGetFlags ${SectionShortcuts} $0
  IntOp $0 $0 | ${SF_EXPAND}
  SectionSetFlags ${SectionShortcuts} $0

; ****************

!ifdef BUILD_WITH_LANGPACKS
; automatically choose language pack to install
 StrCmp $LANGUAGE ${LANG_POLISH} 0 +2
  SectionSetFlags ${LangPL} ${SF_SELECTED}
 StrCmp $LANGUAGE ${LANG_FRENCH} 0 +2
  SectionSetFlags ${LangFR} ${SF_SELECTED}
 StrCmp $LANGUAGE ${LANG_GREEK} 0 +2
  SectionSetFlags ${LangGR} ${SF_SELECTED}
 StrCmp $LANGUAGE ${LANG_DUTCH} 0 +2
  SectionSetFlags ${LangNL} ${SF_SELECTED}
 StrCmp $LANGUAGE ${LANG_ITALIAN} 0 +2
  SectionSetFlags ${LangIT} ${SF_SELECTED}
 StrCmp $LANGUAGE ${LANG_MACEDONIAN} 0 +2
  SectionSetFlags ${LangMK} ${SF_SELECTED}
 StrCmp $LANGUAGE ${LANG_SLOVAK} 0 +2
  SectionSetFlags ${LangSK} ${SF_SELECTED}
 StrCmp $LANGUAGE ${LANG_SWEDISH} 0 +2
  SectionSetFlags ${LangSE} ${SF_SELECTED}
 StrCmp $LANGUAGE ${LANG_SPANISH} 0 +2
  SectionSetFlags ${LangES} ${SF_SELECTED}
 StrCmp $LANGUAGE ${LANG_CZECH} 0 +2
  SectionSetFlags ${LangCS} ${SF_SELECTED}
 StrCmp $LANGUAGE ${LANG_CATALAN} 0 +2
  SectionSetFlags ${LangCA} ${SF_SELECTED}
 StrCmp $LANGUAGE ${LANG_SIMPCHINESE} 0 +2
  SectionSetFlags ${LangZH} ${SF_SELECTED}
 StrCmp $LANGUAGE ${LANG_GERMAN} 0 +2
  SectionSetFlags ${LangDE} ${SF_SELECTED}
  ; *** FOLLOW THE PATTERN WHEN ADDING LANGUAGES
; ****************
!endif

  StrCpy $DONE_INIT "0"
  ; init strings now

FunctionEnd

; ******************************************************
; Uninstall functions

; function that checks if the user running the UNinstaller is an Administrator
Function un.IsUserAdmin
 Push $R0
 Push $R1
 Push $R2

 ClearErrors
 UserInfo::GetName
 IfErrors Win9x
 Pop $R1
 UserInfo::GetAccountType
 Pop $R2

 StrCmp $R2 "Admin" 0 Continue
 StrCpy $R0 "true"
 Goto Done

 Continue:
  StrCmp $R2 "" Win9x
 StrCpy $R0 "false"
  Goto Done

 Win9x:
  StrCpy $R0 "true"

 Done:
 Pop $R2
 Pop $R1
 Exch $R0
FunctionEnd

; ********************************
; Close Psi Instances
; Waits for all running instances of Psi to close
Function un.ClosePsiInstances
    Push $0 ;saving stack
  newcheck:
    FindWindow $0 "TkabberClassName" "TkabberWindowTitle" 0
    IntCmp $0 0 done
    MessageBox MB_RETRYCANCEL|MB_ICONEXCLAMATION "$LSTR_ASK_EXIT_PSI" IDRETRY newcheck
    ; cancel
    Quit
  done:
    Pop $0 ; restoring stack
FunctionEnd

Function un.InitRoutines

; MessageBox MB_OK "Uninstalling"

 StrCmp $DONE_INIT "1" done_un_init

 StrCpy $DONE_INIT "1"

; initializing the strings with the coresponding ones in the active language
 StrCpy $LSTR_PSIBASE         "Tkabber"
 StrCpy $LSTR_LANGUAGES       "Languages"
 StrCpy $LSTR_CURRENTUSER     "Current User"
 StrCpy $LSTR_ALLUSERS        "All Users"
 StrCpy $LSTR_SHORTCUTS       "Shortcuts"
 StrCpy $LSTR_QUICKLAUNCH     "Quick Launch shortcut"
 StrCpy $LSTR_DESKTOP_S       "Desktop shortcut"
 StrCpy $LSTR_STARTMENU_GROUP "Start Menu group"
 StrCpy $LSTR_AUTOSTART       "Automatic startup"
 StrCpy $LSTR_ASK_EXIT_PSI    "You must exit all running copies of Tkabber to continue!"
 StrCpy $LSTR_UNINST_RUNNING  "The uninstaller is already running."
 StrCpy $LSTR_INST_RUNNING    "The installer is already running."
 StrCpy $LSTR_WARN_ADMIN_1    "You are running this installer as a normal user, NOT as an Administrator."
 StrCpy $LSTR_WARN_ADMIN_2    "If you want to uninstall this application, you must use the same user or your system may become unstable."
 StrCpy $LSTR_A_INSTALLED     "Tkabber is already installed. $\n$\nClick <OK> to remove the previous version or <Cancel> to cancel this upgrade."
 StrCpy $LSTR_ERR_UNINST      "There were some errors uninstalling Tkabber. $\n$\nWould you like to continue?"

 StrCmp $(STR_PSIBASE) "" +2
    StrCpy $LSTR_PSIBASE $(STR_PSIBASE)
 StrCmp $(STR_LANGUAGES) "" +2
    StrCpy $LSTR_LANGUAGES $(STR_LANGUAGES)
 StrCmp $(STR_CURRENTUSER) "" +2
    StrCpy $LSTR_CURRENTUSER $(STR_CURRENTUSER)
 StrCmp $(STR_ALLUSERS) "" +2
    StrCpy $LSTR_ALLUSERS $(STR_ALLUSERS)
 StrCmp $(STR_SHORTCUTS) "" +2
    StrCpy $LSTR_SHORTCUTS $(STR_SHORTCUTS)
 StrCmp $(STR_QUICKLAUNCH) "" +2
    StrCpy $LSTR_QUICKLAUNCH $(STR_QUICKLAUNCH)
 StrCmp $(STR_DESKTOP_S) "" +2
    StrCpy $LSTR_DESKTOP_S $(STR_DESKTOP_S)
 StrCmp $(STR_STARTMENU_GROUP) "" +2
    StrCpy $LSTR_STARTMENU_GROUP $(STR_STARTMENU_GROUP)
 StrCmp $(STR_AUTOSTART) "" +2
    StrCpy $LSTR_AUTOSTART $(STR_AUTOSTART)
 StrCmp $(STR_ASK_EXIT_PSI) "" +2
    StrCpy $LSTR_ASK_EXIT_PSI $(STR_ASK_EXIT_PSI)
 StrCmp $(STR_UNINST_RUNNING) "" +2
    StrCpy $LSTR_UNINST_RUNNING $(STR_UNINST_RUNNING)
 StrCmp $(STR_INST_RUNNING) "" +2
    StrCpy $LSTR_INST_RUNNING $(STR_INST_RUNNING)
 StrCmp $(STR_WARN_ADMIN_1) "" +2
    StrCpy $LSTR_WARN_ADMIN_1 $(STR_WARN_ADMIN_1)
 StrCmp $(STR_WARN_ADMIN_2) "" +2
    StrCpy $LSTR_WARN_ADMIN_2 $(STR_WARN_ADMIN_2)
 StrCmp $(STR_A_INSTALLED) "" +2
    StrCpy $LSTR_A_INSTALLED $(STR_A_INSTALLED)
 StrCmp $(STR_ERR_UNINST) "" +2
    StrCpy $LSTR_ERR_UNINST $(STR_ERR_UNINST)

; allow only one instance of the uninstaller
  System::Call 'kernel32::CreateMutexA(i 0, i 0, t "Tkabber-Pack${APPVERSION}-uninstaller") i .r1 ?e'
  Pop $R0
  StrCmp $R0 0 +3
    MessageBox MB_OK "$LSTR_UNINST_RUNNING"
    Abort

  ;ask the user to close all psi instances on uninstall
  Call un.ClosePsiInstances
  done_un_init:
FunctionEnd

Function un.onInit
; ****************
  ;uninstall saved language setting
  !insertmacro MUI_UNGETLANGUAGE

  StrCpy $DONE_INIT "0"

FunctionEnd

;Uninstall section
Section Uninstall
  ;Remove from registry...
 Call un.IsUserAdmin
 Pop $R0
 StrCmp $R0 "true" uninstall_is_admin
   DeleteRegKey HKCU "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPNAME}"
   DeleteRegKey HKCU "Software\${APPNAME}"
   Goto uninstall_done
  uninstall_is_admin:
   DeleteRegKey HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPNAME}"
   DeleteRegKey HKLM "Software\${APPNAME}"
  uninstall_done:

  ; Delete self
  Delete "$INSTDIR\uninstall.exe"

  ; Delete links
;  Delete "$INSTDIR\Psi - Forum.url";
;  Delete "$INSTDIR\Psi - Home page.url";
;  Delete "$INSTDIR\Psi - Documentation.url";

  ; Delete Shortcuts
  SetShellVarContext current
  Delete "$DESKTOP\Tkabber.lnk"
  Delete "$SMPROGRAMS\Tkabber\Tkabber.lnk"
  Delete "$SMPROGRAMS\Tkabber\Uninstall.lnk"
;  Delete "$SMPROGRAMS\Psi\ReadME.lnk"
  Delete "$QUICKLAUNCH\Tkabber.lnk"
;  Delete "$SMPROGRAMS\Psi\Psi - Forum.lnk"
;  Delete "$SMPROGRAMS\Psi\Psi - Home page.lnk"
;  RMDir "$SMPROGRAMS\Psi"

  SetShellVarContext all
  Delete "$DESKTOP\Tkabber.lnk"
  Delete "$SMPROGRAMS\Tkabber\Tkabber.lnk"
  Delete "$SMPROGRAMS\Tkabber\Uninstall.lnk"
;  Delete "$SMPROGRAMS\Psi\ReadME.lnk"
  Delete "$QUICKLAUNCH\Tkabber.lnk"
;  Delete "$SMPROGRAMS\Psi\Psi - Forum.lnk"
;  Delete "$SMPROGRAMS\Psi\Psi - Home page.lnk"
;  RMDir "$SMPROGRAMS\Psi"

  ; DeleteRegValue HKCU "Software\Microsoft\Windows\CurrentVersion\Run" "Psi"
  ; ^ Registry shortcut doesn't work
  SetShellVarContext current
  Delete "$SMSTARTUP\Tkabber.lnk"

!ifdef BUILD_WITH_LANGPACKS
  ; Delete Language files
  Delete "$INSTDIR\psi_el.qm"
  Delete "$INSTDIR\psi_es.qm"
  Delete "$INSTDIR\psi_fr.qm"
  Delete "$INSTDIR\psi_it.qm"
  Delete "$INSTDIR\psi_mk.qm"
  Delete "$INSTDIR\psi_nl.qm"
  Delete "$INSTDIR\psi_pl.qm"
  Delete "$INSTDIR\psi_se.qm"
  Delete "$INSTDIR\psi_sk.qm"
  Delete "$INSTDIR\psi_cs.qm"
  Delete "$INSTDIR\psi_ca.qm"
  Delete "$INSTDIR\psi_zh.qm"
  Delete "$INSTDIR\psi_de.qm"
  ; *** FOLLOW THE PATTERN WHEN ADDING LANGUAGES
!endif

  ; Clean up Psi (base)
  !include "psi_files_uninstall.nsi"
SectionEnd


Function UninstallPreviousPsi

 Call IsUserAdmin
 Pop $R0
 StrCpy $RUN_BY_ADMIN $R0 ; saving information
 StrCmp $R0 "true" unppsi_is_admin
  ReadRegStr $R0 HKCU "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPNAME}" "UninstallString"
	ReadRegStr $R1 HKCU "Software\${APPNAME}" ""
  goto unppsi_done
 unppsi_is_admin:
  ReadRegStr $R0 HKLM "Software\Microsoft\Windows\CurrentVersion\Uninstall\${APPNAME}" "UninstallString"
	ReadRegStr $R1 HKCU "Software\${APPNAME}" ""
 unppsi_done:
  ; $R0 holds the path to the uninstaller
	; $R1 holds the install dir
  StrCmp $R0 "" auto_uninstall_done

  MessageBox MB_OKCANCEL|MB_ICONEXCLAMATION "$LSTR_A_INSTALLED" \
   IDOK auto_uninstall \
   IDCANCEL auto_uninstall_cancel

  ;Run the uninstaller
  auto_uninstall:
   ClearErrors
   ExecWait '$R0 _?=$INSTDIR' ;Do not copy the uninstaller to a temp file

   IfErrors no_remove_uninstaller
   Goto auto_uninstall_done

  no_remove_uninstaller:
  MessageBox MB_YESNO|MB_ICONQUESTION "$LSTR_ERR_UNINST" \
   IDYES auto_uninstall_done \

  auto_uninstall_cancel:
   Abort
  
  auto_uninstall_done:

FunctionEnd

; eof
